<?php

namespace SimpleSAML\Error;

/**
 * Exception indicating illegal innput from user.
 *
 * @author Thomas Graff <thomas.graff@uninett.no>
 * @package SimpleSAMLphp_base
 *
 */

class BadUserInput extends User
{
}
